@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002 Red Hat, Inc.
+ * Copyright (C) 2002,2003 Red Hat, Inc.
  *
  * This is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Library General Public License as published by
@@ -16,9 +16,9 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: debug.c,v 1.12 2002/12/10 22:36:29 nalin Exp $"
 #include "../config.h"
 #include <glib.h>
+#include <stdio.h>
 #include "debug.h"
 
 static VteDebugFlags _vte_debug_flags = 0;
@@ -73,6 +73,9 @@ _vte_debug_parse_string(const char *string)
 			} else
 			if (g_ascii_strcasecmp(flags[i], "LIFECYCLE") == 0) {
 				_vte_debug_flags |= VTE_DEBUG_LIFECYCLE;
+			} else
+			if (g_ascii_strcasecmp(flags[i], "TRIE") == 0) {
+				_vte_debug_flags |= VTE_DEBUG_TRIE;
 			}
 		}
 		g_strfreev(flags);
@@ -82,5 +85,8 @@ _vte_debug_parse_string(const char *string)
 gboolean
 _vte_debug_on(VteDebugFlags flags)
 {
+#ifdef VTE_DEBUG
+	fflush(NULL);
+#endif
 	return (_vte_debug_flags & flags) == flags;
 }
