@@ -20,11 +20,18 @@
 
 #include "../config.h"
 
+#include <stdarg.h>
+
 #ifdef HAVE_NCURSES
 #include <ncurses.h>
 #include <term.h>
 #define HAVE_CURSES
 #else
+#ifdef HAVE_NCURSES_CURSES
+#include <ncurses/curses.h>
+#include <ncurses/term.h>
+#define HAVE_CURSES
+#else
 #ifdef HAVE_CURSES
 #include <curses.h>
 #include <term.h>
@@ -34,17 +41,23 @@
 #endif
 #endif
 #endif
+#endif
 
 #include <sys/types.h>
-#include <sys/time.h>
 #include <sys/ioctl.h>
+#ifdef HAVE_SYS_TERMIOS_H
+#include <sys/termios.h>
+#endif
+#include <sys/time.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#ifdef HAVE_TERMIOS_H
 #include <termios.h>
+#endif
 #include <time.h>
 #include <unistd.h>
 
